block_dominates

Function block_dominates 

fn block_dominates(body: &Body<'_>, a: BasicBlock, b: BasicBlock) -> bool
Whether block a dominates block b (every path from the entry to b passes through a). Simple BFS: a dominates b iff b is not reachable from the entry when a is skipped.