pub(super) fn callee_calls_other_local(tcx: TyCtxt<'_>, callee: DefId) -> boolExpand description
Return true if the callee body contains any Call terminator, meaning the callee is not self-contained (a nested call may have side effects that a shallow summary cannot capture).