detect_index_disjoint_validator

Function detect_index_disjoint_validator 

pub(super) fn detect_index_disjoint_validator(
    tcx: TyCtxt<'_>,
    callee: DefId,
) -> Option<(usize, usize)>
Detect an “index disjoint validator”: a function whose body loads elements from an array argument, and returns early (Err) both when an element is out of range against a scalar argument (>= len) and when two elements are equal (a duplicate). Returns (indices_arg, len_arg).