single_call_wrapper_target

Function single_call_wrapper_target 

fn single_call_wrapper_target<'tcx>(
    tcx: TyCtxt<'tcx>,
    callee: DefId,
) -> Option<DefId>
The callee delegated to by a thin wrapper whose body is a single call returning directly into _0 (e.g. slice::iter → Iter::new).